==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/AppAndInstancePolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AppAndInstanceConditionEvaluatorAppOrInstance;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AppAndInstancePolicyRuleCondition
 */
@JsonPropertyOrder({ AppAndInstancePolicyRuleCondition.JSON_PROPERTY_EXCLUDE,
        AppAndInstancePolicyRuleCondition.JSON_PROPERTY_INCLUDE })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AppAndInstancePolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EXCLUDE = "exclude";
    private List<AppAndInstanceConditionEvaluatorAppOrInstance> exclude = null;

    public static final String JSON_PROPERTY_INCLUDE = "include";
    private List<AppAndInstanceConditionEvaluatorAppOrInstance> include = null;

    public AppAndInstancePolicyRuleCondition() {
    }

    public AppAndInstancePolicyRuleCondition exclude(List<AppAndInstanceConditionEvaluatorAppOrInstance> exclude) {

        this.exclude = exclude;
        return this;
    }

    public AppAndInstancePolicyRuleCondition addexcludeItem(AppAndInstanceConditionEvaluatorAppOrInstance excludeItem) {
        if (this.exclude == null) {
            this.exclude = new ArrayList<>();
        }
        this.exclude.add(excludeItem);
        return this;
    }

    /**
     * The list of applications to exclude
     *
     * @return exclude
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The list of applications to exclude")
    @JsonProperty(JSON_PROPERTY_EXCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<AppAndInstanceConditionEvaluatorAppOrInstance> getExclude() {
        return exclude;
    }

    @JsonProperty(JSON_PROPERTY_EXCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setExclude(List<AppAndInstanceConditionEvaluatorAppOrInstance> exclude) {
        this.exclude = exclude;
    }

    public AppAndInstancePolicyRuleCondition include(List<AppAndInstanceConditionEvaluatorAppOrInstance> include) {

        this.include = include;
        return this;
    }

    public AppAndInstancePolicyRuleCondition addincludeItem(AppAndInstanceConditionEvaluatorAppOrInstance includeItem) {
        if (this.include == null) {
            this.include = new ArrayList<>();
        }
        this.include.add(includeItem);
        return this;
    }

    /**
     * The list of apps or app instances to match on
     *
     * @return include
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The list of apps or app instances to match on")
    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<AppAndInstanceConditionEvaluatorAppOrInstance> getInclude() {
        return include;
    }

    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInclude(List<AppAndInstanceConditionEvaluatorAppOrInstance> include) {
        this.include = include;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AppAndInstancePolicyRuleCondition appAndInstancePolicyRuleCondition = (AppAndInstancePolicyRuleCondition) o;
        return Objects.equals(this.exclude, appAndInstancePolicyRuleCondition.exclude)
                && Objects.equals(this.include, appAndInstancePolicyRuleCondition.include);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(exclude, include);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AppAndInstancePolicyRuleCondition {\n");
        sb.append("    exclude: ").append(toIndentedString(exclude)).append("\n");
        sb.append("    include: ").append(toIndentedString(include)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/AppAndInstancePolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AppAndInstanceConditionEvaluatorAppOrInstance;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * AppAndInstancePolicyRuleCondition
 */
@JsonPropertyOrder({ AppAndInstancePolicyRuleCondition.JSON_PROPERTY_EXCLUDE,
        AppAndInstancePolicyRuleCondition.JSON_PROPERTY_INCLUDE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class AppAndInstancePolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EXCLUDE = "exclude";
    private List<AppAndInstanceConditionEvaluatorAppOrInstance> exclude = null;

    public static final String JSON_PROPERTY_INCLUDE = "include";
    private List<AppAndInstanceConditionEvaluatorAppOrInstance> include = null;

    public AppAndInstancePolicyRuleCondition() {
    }

    public AppAndInstancePolicyRuleCondition exclude(List<AppAndInstanceConditionEvaluatorAppOrInstance> exclude) {

        this.exclude = exclude;
        return this;
    }

    public AppAndInstancePolicyRuleCondition addexcludeItem(AppAndInstanceConditionEvaluatorAppOrInstance excludeItem) {
        if (this.exclude == null) {
            this.exclude = new ArrayList<>();
        }
        this.exclude.add(excludeItem);
        return this;
    }

    /**
     * The list of applications to exclude
     *
     * @return exclude
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The list of applications to exclude")
    @JsonProperty(JSON_PROPERTY_EXCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<AppAndInstanceConditionEvaluatorAppOrInstance> getExclude() {
        return exclude;
    }

    @JsonProperty(JSON_PROPERTY_EXCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setExclude(List<AppAndInstanceConditionEvaluatorAppOrInstance> exclude) {
        this.exclude = exclude;
    }

    public AppAndInstancePolicyRuleCondition include(List<AppAndInstanceConditionEvaluatorAppOrInstance> include) {

        this.include = include;
        return this;
    }

    public AppAndInstancePolicyRuleCondition addincludeItem(AppAndInstanceConditionEvaluatorAppOrInstance includeItem) {
        if (this.include == null) {
            this.include = new ArrayList<>();
        }
        this.include.add(includeItem);
        return this;
    }

    /**
     * The list of apps or app instances to match on
     *
     * @return include
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The list of apps or app instances to match on")
    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<AppAndInstanceConditionEvaluatorAppOrInstance> getInclude() {
        return include;
    }

    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInclude(List<AppAndInstanceConditionEvaluatorAppOrInstance> include) {
        this.include = include;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AppAndInstancePolicyRuleCondition appAndInstancePolicyRuleCondition = (AppAndInstancePolicyRuleCondition) o;
        return Objects.equals(this.exclude, appAndInstancePolicyRuleCondition.exclude)
                && Objects.equals(this.include, appAndInstancePolicyRuleCondition.include);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(exclude, include);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AppAndInstancePolicyRuleCondition {\n");
        sb.append("    exclude: ").append(toIndentedString(exclude)).append("\n");
        sb.append("    include: ").append(toIndentedString(include)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
